@@ -237,10 +237,14 @@ void Groupsock::removeAllDestinations() {
 }
 
 void Groupsock::multicastSendOnly() {
+  // We disable this code for now, because - on some systems - leaving the multicast group seems to cause sent packets
+  // to not be received by other applications (at least, on the same host).
+#if 0
   socketLeaveGroup(env(), socketNum(), fIncomingGroupEId.groupAddress().s_addr);
   for (destRecord* dests = fDests; dests != NULL; dests = dests->fNext) {
     socketLeaveGroup(env(), socketNum(), dests->fGroupEId.groupAddress().s_addr);
   }
+#endif
 }
 
 Boolean Groupsock::output(UsageEnvironment& env, u_int8_t ttlToSend,
