@@ -11,10 +11,10 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2007 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2010 Live Networks, Inc.  All rights reserved.
 // AMR Audio File sinks
 // Implementation
 
@@ -26,7 +26,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 
 AMRAudioFileSink
 ::AMRAudioFileSink(UsageEnvironment& env, FILE* fid, unsigned bufferSize,
-		   char const* perFrameFileNamePrefix) 
+		   char const* perFrameFileNamePrefix)
   : FileSink(env, fid, bufferSize, perFrameFileNamePrefix),
     fHaveWrittenHeader(False) {
 }
@@ -65,10 +65,11 @@ Boolean AMRAudioFileSink::sourceIsCompatibleWithUs(MediaSource& source) {
 void AMRAudioFileSink::afterGettingFrame1(unsigned frameSize,
 					  struct timeval presentationTime) {
   AMRAudioSource* source = (AMRAudioSource*)fSource;
+  if (source == NULL) return; // sanity check
 
   if (!fHaveWrittenHeader && fPerFrameFileNameBuffer == NULL) {
     // Output the appropriate AMR header to the start of the file.
-    // This header is defined in RFC 3267, section 5. 
+    // This header is defined in RFC 3267, section 5.
     // (However, we don't do this if we're creating one file per frame.)
     char headerBuffer[100];
     sprintf(headerBuffer, "#!AMR%s%s\n",
